/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 29/10/2024
 */

#include "net.h"

namespace vampiria { namespace net {

void empty_recvfrom_ev(event::Cell *cell,vmp::Buf *buf,net::Address *peer)
{
}

void empty_accept_ev(event::Cell *listen,event::Cell *server)
{
}

vmp_uint empty_socksnoauth_ev(event::Cell *cell)
{
    return 0;
}

vmp_uint empty_socksuserpass_ev(event::Cell *cell,vmp::str user,vmp::str password)
{
    return 0;
}

void empty_socksrequest_ev(event::Cell *cell,net::Address *address)
{
}

}}

